#include <QImage>
#include <QString>
#include <QColor>
#include "bsdetector.h"
#include "vmap.h"

#include <iostream>
#include <fstream>



void usage(std::string str)
{
  std::cout << str << " : something is wrong with the prog parameter (not enough parameters or something wrong)... "<< std::endl;  

}



int main (int argc, char *argv[])
{
  if (argc < 3)
  {
    usage(argv[0]);
    exit(EXIT_FAILURE);
  }

  
  // getting parameters:
  // - input file
  string input_filename = argv[1];
  // - output file
  string output_filename = argv[2];
  ofstream fout;  
  fout.open(output_filename.c_str(), std::fstream::out);

  
// Calcul de la carte de gradient (utilise qt)
  QImage image;
  
  image.load (QString (input_filename.c_str()));
  int width = image.width ();
  int height = image.height ();
  int **tabImage = new int*[height];
  for (int i = 0; i < height; i++)
  {
    tabImage[i] = new int[width];
    for(int j = 0; j < width; j++)
    {
      QColor c = QColor (image.pixel (j, height - i - 1));
      tabImage[i][j] = c.value ();
    }
  }
  VMap *gMap = new VMap (width, height, tabImage, VMap::TYPE_SOBEL_5X5);

  // Detection
  BSDetector detector;
  detector.setGradientMap (gMap);
  detector.setMaxTrials (-1);
  detector.detectAll ();

  fout << "# Line detection generated from " << argv[0] << "with format : X1 Y1 X2 Y2 on each line" << std::endl;
  
  // Affichage
  vector<BlurredSegment *> bss = detector.getBlurredSegments ();
  if (! bss.empty ())
  {
    vector<BlurredSegment *>::const_iterator it = bss.begin ();
    while (it != bss.end ())
    {
      // Affichage du premier point
      vector<Pt2i> points = (*it)->getAllPoints ();
      
      fout <<  points.front().x() << " " << points.front().y() << " "
                <<  points.back().x() << " " << points.back().y() << std::endl;
      
      // Affichage du DSS englobant
      // vector<Pt2i> bnd;
      // DigitalStraightSegment *dss = (*it)->getSegment ();
      // if (dss != NULL)
      // {
         
      //   dss->getBounds (bnd, 0, 0, width, height, false);
      //   // cout << "DSS starts from (" << bnd.front().x()
      //   //    << "," << bnd.front().y() << ")" << endl;
      //   auto b = bnd.begin();
      //   for (auto &x: bnd){
      //   cout << "DSS starts from (" << x.x()
      //        << "," << x.y() << ")" << endl;
          
      //   }
      // }

      it++;
    }
  }
  fout.close();
  return (0);
}
